.TH domi 8
.SH NAME
domi - xen domain installer
.SH SYNOPSIS
domi config-file
.SH DESCRIPTION
domi is a shell script which sets up virtual machines.  It creates
virtual disks using either LVM or image files and installs a linux
distribution on the newly created disk.
.P
domi reads the configuration from /etc/domi.conf and the config file
passed on the command line.  Then goes ahead and sets up the virtual
disk without asking further questions, so be careful.
.SH DOMI OPTIONS
The config files are simply sourced.  Thus the syntax for setting the
config options is the usual shell variable style, i.e. VAR="value",
hashmark works for comments and so on.
.TP
DOMI_NAME
.B Required.
.br
Name of the virtual machine.
.TP
DOMI_DISTRO
.B Required.
.br
Distribution to install.  Valid choices are suse, fedora, debian and
gentoo.
.TP
DOMI_CACHE
Default: /var/cache/domi
.br
Location where downloaded files are cached.
.TP
DOMI_FSTYPE
Default: ext2
.br
File system to use.
.TP
DOMI_PASSWD
Default: root
.br
Initial root password.
.TP
DOMI_VDISK
Default: xvda
.br
Name of the virtual disk (inside the vm).  "xvda" should do just
fine with all modern, udev-based distros which create the device
nodes automatically.  In case of trouble you can try "hda" instead.
.TP
DOMI_XEN_CONF
.B Recommended.
.br
If specified the script writes a initial Xen config file to the given
location.
.TP
DOMI_XEN_KERNEL
Default: /boot/vmlinuz-xen
.br
Xen kernel (for the Xen config file).
.TP
DOMI_XEN_MEMORY
Default: 128
.br
Main memory (for the Xen config file, in megabytes).
.TP
DOMI_XEN_BOOT
Default: no
.br
Enabling this one makes domi switch to a completely different install
mode:  It boots the distribution installer.  Works for cutting edge SUSE
and Fedora distros.
.TP
DOMI_DISK_VG
.B Recommended.
.br
LVM volume group to use for storage.  If specified the script will
create a volume with DOMI_NAME in that volume group and use it to
setup the virtual disk.
.TP
DOMI_DISK_FILE
If you don't use LVM you can specify an image file to use for the
virtual disk.  Setting either DOMI_DISK_VG or DOMI_DISK_FILE is
required.
.TP
DOMI_DISK_SPARSE
Set this to some non-empty value to make domi use sparse file for the
disk images.  Has no effect if you use LVM.
.TP
DOMI_DISK_SIZE
Default: 4096
.br
Size of the virtual disk, in megabytes.
.TP
DOMI_SWAP_SIZE
Default: 256
.br
Size of the swap partition, in megabytes.
.TP
DOMI_ROOT_SIZE
Default: DOMI_DISK_SIZE - DOMI_SWAP_SIZE
.br
Size if the root filesystem, in megabytes
.TP
DOMI_HOOK_POST
.br
Custom postinstall script to run.
.SH SUSE OPTIONS
.TP
SUSE_SOURCE
Default: http://ftp.opensuse.org/pub/opensuse/distribution/SL-10.0-OSS/inst-source/
.br
Installation source.
.TP
SUSE_SELECTIONS
Default: Minimal+X11
.br
Package selection to install.
.TP
SUSE_PACKAGES
Default: kernel-xen
.br
Extra packages to install.
.TP
SUSE_MODE
Default: autodetected
.br
Installation mode (y2pmsh or yum).
.P
Notes: y2pmsh mode works better.  Drawback is it works on suse systems
only.  It also doesn't cache the RPMS downloaded, so better install
from a local copy of the installation media rather than directly from
the internet.  yum mode works with the OSS release of 10.0 only and also
doesn't work with selections (aka groups) because the repository lacks
the metadata needed for that.
.SH FEDORA OPTIONS
.TP
FEDORA_REPO
Default: http://download.fedora.redhat.com/pub/fedora/linux/core/4/i386/os/
.br
Fedora package repository.
.TP
FEDORA_GROUP
Default: Base
.br
Package group to install.
.TP
FEDORA_PACKAGES
.br
Additional packages to install.
.P
The fedora installer uses yum to do the job, so other distros which use
yum should be installable as well.
.SH DEBIAN OPTIONS
.TP
DEBIAN_MIRROR
Default: http://ftp.debian.org
.br
Debian mirror to use.
.TP
DEBIAN_RELEASE
Default: sarge
.br
Debian release to install.
.TP
DEBIAN_PACKAGES
.br
Extra packages to install.
.P
The debian installer uses debootstrap and should also work with
other debian-based distros such as ubuntu.
.SH GENTOO OPTIONS
.TP
GENTOO_MIRROR
Default: http://ftp.belnet.be/mirror/rsync.gentoo.org/gentoo
.br
Gentoo mirror to use.
.TP
GENTOO_BUILD
.br
Extra packages, compile and install.
.TP
GENTOO_FETCH
.br
Extra packages, fetch distfiles only.
.SH FILES
/etc/domi.conf
.SH SEE ALSO
parted(8), kpartx(8), lvm(8)
.SH AUTHOR
Gerd Knorr <kraxel@suse.de>
